==> jc-1.4.0.tar.gz: javax/crypto/spec/RC5ParameterSpec.h <==
// public class javax.crypto.spec.RC5ParameterSpec

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 595c0bf23b2acb5e javax_crypto_spec_RC5ParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_RC5ParameterSpec_H_
#define _JC_javax_crypto_spec_RC5ParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$sub_refs	_jc_javax_crypto_spec_RC5ParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_RC5ParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$refs	_jc_javax_crypto_spec_RC5ParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$nonrefs	_jc_javax_crypto_spec_RC5ParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$object	_jc_javax_crypto_spec_RC5ParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_RC5ParameterSpec$vmethods	_jc_javax_crypto_spec_RC5ParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_RC5ParameterSpec$vtable	_jc_javax_crypto_spec_RC5ParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_RC5ParameterSpec$vtype	_jc_javax_crypto_spec_RC5ParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_RC5ParameterSpec$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, jint, jint, jint);
extern void _jc_javax_crypto_spec_RC5ParameterSpec$method$_init$72d839214131c6e4(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, jint, jint, jint, struct _jc_byte_array *);
extern void _jc_javax_crypto_spec_RC5ParameterSpec$method$_init$6b91d988b6c4f745(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, jint, jint, jint, struct _jc_byte_array *, jint);

// Virtual methods
extern jboolean _jc_javax_crypto_spec_RC5ParameterSpec$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, struct _jc_java_lang_Object$object *);
extern _jc_byte_array *_jc_javax_crypto_spec_RC5ParameterSpec$method$getIV$4134a0c13b73072e(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
extern jint _jc_javax_crypto_spec_RC5ParameterSpec$method$getRounds$3ed9ef928a21204e(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
extern jint _jc_javax_crypto_spec_RC5ParameterSpec$method$getVersion$b5e412566904b7c3(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
extern jint _jc_javax_crypto_spec_RC5ParameterSpec$method$getWordSize$0d98f34fe9b5820d(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
extern jint _jc_javax_crypto_spec_RC5ParameterSpec$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$getIV$4134a0c13b73072e;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$getRounds$3ed9ef928a21204e;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$getVersion$b5e412566904b7c3;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$getWordSize$0d98f34fe9b5820d;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_crypto_spec_RC5ParameterSpec$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, struct _jc_java_lang_Object$object *);
	_jc_byte_array	*(*getIV$4134a0c13b73072e)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
	jint	(*getRounds$3ed9ef928a21204e)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
	jint	(*getVersion$b5e412566904b7c3)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
	jint	(*getWordSize$0d98f34fe9b5820d)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *);
};

// Vtable
struct _jc_javax_crypto_spec_RC5ParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_RC5ParameterSpec$vmethods	javax_crypto_spec_RC5ParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_RC5ParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_RC5ParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_RC5ParameterSpec$sub_refs {
	_jc_byte_array	*iv;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_RC5ParameterSpec$refs {
    _jc_javax_crypto_spec_RC5ParameterSpec$sub_refs	javax_crypto_spec_RC5ParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_RC5ParameterSpec$sub_nonrefs {
	jint	rounds;
	jint	version;
	jint	wordSize;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_RC5ParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_RC5ParameterSpec$sub_nonrefs	javax_crypto_spec_RC5ParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_RC5ParameterSpec$object {
	_jc_javax_crypto_spec_RC5ParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_RC5ParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_RC5ParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_RC5ParameterSpec$vtype _jc_javax_crypto_spec_RC5ParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_RC5ParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_RC5ParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_RC5ParameterSpec_H_ */

==> jc-1.4.6.tar.gz: javax/crypto/spec/RC5ParameterSpec.h <==
// public class javax.crypto.spec.RC5ParameterSpec

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 595c0bf23b2acb5e javax_crypto_spec_RC5ParameterSpec

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_javax_crypto_spec_RC5ParameterSpec_H_
#define _JC_javax_crypto_spec_RC5ParameterSpec_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;

// Typedefs
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$sub_refs	_jc_javax_crypto_spec_RC5ParameterSpec$sub_refs;
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$sub_nonrefs	_jc_javax_crypto_spec_RC5ParameterSpec$sub_nonrefs;
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$refs	_jc_javax_crypto_spec_RC5ParameterSpec$refs;
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$nonrefs	_jc_javax_crypto_spec_RC5ParameterSpec$nonrefs;
typedef struct _jc_javax_crypto_spec_RC5ParameterSpec$object	_jc_javax_crypto_spec_RC5ParameterSpec$object;

typedef const struct _jc_javax_crypto_spec_RC5ParameterSpec$vmethods	_jc_javax_crypto_spec_RC5ParameterSpec$vmethods;
typedef const struct _jc_javax_crypto_spec_RC5ParameterSpec$vtable	_jc_javax_crypto_spec_RC5ParameterSpec$vtable;
typedef const struct _jc_javax_crypto_spec_RC5ParameterSpec$vtype	_jc_javax_crypto_spec_RC5ParameterSpec$vtype;

// Constructors
extern void _jc_javax_crypto_spec_RC5ParameterSpec$method$_init$bfb53a4355ec1401(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, jint, jint, jint) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_RC5ParameterSpec$method$_init$72d839214131c6e4(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, jint, jint, jint, struct _jc_byte_array *) _JC_JCNI_ATTR;
extern void _jc_javax_crypto_spec_RC5ParameterSpec$method$_init$6b91d988b6c4f745(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, jint, jint, jint, struct _jc_byte_array *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_javax_crypto_spec_RC5ParameterSpec$method$equals$8a15e0625571c581(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_javax_crypto_spec_RC5ParameterSpec$method$getIV$4134a0c13b73072e(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_RC5ParameterSpec$method$getRounds$3ed9ef928a21204e(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_RC5ParameterSpec$method$getVersion$b5e412566904b7c3(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_RC5ParameterSpec$method$getWordSize$0d98f34fe9b5820d(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
extern jint _jc_javax_crypto_spec_RC5ParameterSpec$method$hashCode$53152098849316df(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$getIV$4134a0c13b73072e;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$getRounds$3ed9ef928a21204e;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$getVersion$b5e412566904b7c3;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$getWordSize$0d98f34fe9b5820d;
extern _jc_method _jc_javax_crypto_spec_RC5ParameterSpec$method_info$hashCode$53152098849316df;

// Virtual methods structure
struct _jc_javax_crypto_spec_RC5ParameterSpec$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getIV$4134a0c13b73072e)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
	jint	(*getRounds$3ed9ef928a21204e)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
	jint	(*getVersion$b5e412566904b7c3)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
	jint	(*getWordSize$0d98f34fe9b5820d)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_javax_crypto_spec_RC5ParameterSpec$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_crypto_spec_RC5ParameterSpec$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_crypto_spec_RC5ParameterSpec$vmethods	javax_crypto_spec_RC5ParameterSpec;
};

// Vtype
struct _jc_javax_crypto_spec_RC5ParameterSpec$vtype {
	_jc_type			type;
	_jc_javax_crypto_spec_RC5ParameterSpec$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_crypto_spec_RC5ParameterSpec$sub_refs {
	_jc_byte_array	*iv;
};

// Reference instance fields (object)
struct _jc_javax_crypto_spec_RC5ParameterSpec$refs {
    _jc_javax_crypto_spec_RC5ParameterSpec$sub_refs	javax_crypto_spec_RC5ParameterSpec;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_crypto_spec_RC5ParameterSpec$sub_nonrefs {
	jint	rounds;
	jint	version;
	jint	wordSize;
};

// Non-reference instance fields (object)
struct _jc_javax_crypto_spec_RC5ParameterSpec$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_crypto_spec_RC5ParameterSpec$sub_nonrefs	javax_crypto_spec_RC5ParameterSpec;
};

// Object instance structure
struct _jc_javax_crypto_spec_RC5ParameterSpec$object {
	_jc_javax_crypto_spec_RC5ParameterSpec$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_crypto_spec_RC5ParameterSpec$vtype	*vtype;
	_jc_javax_crypto_spec_RC5ParameterSpec$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_crypto_spec_RC5ParameterSpec$vtype _jc_javax_crypto_spec_RC5ParameterSpec$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_crypto_spec_RC5ParameterSpec, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_crypto_spec_RC5ParameterSpec$class_object;

#endif	/* _JC_javax_crypto_spec_RC5ParameterSpec_H_ */
